You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2015/02/16 23:40:35 UTC

[65/82] [math] Update for next development iteration: commons-math4

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/interval/AgrestiCoullInterval.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/interval/AgrestiCoullInterval.java b/src/main/java/org/apache/commons/math4/stat/interval/AgrestiCoullInterval.java
index b71c718..6685e64 100644
--- a/src/main/java/org/apache/commons/math4/stat/interval/AgrestiCoullInterval.java
+++ b/src/main/java/org/apache/commons/math4/stat/interval/AgrestiCoullInterval.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.interval;
+package org.apache.commons.math4.stat.interval;
 
-import org.apache.commons.math3.distribution.NormalDistribution;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.distribution.NormalDistribution;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Implements the Agresti-Coull method for creating a binomial proportion confidence interval.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/interval/BinomialConfidenceInterval.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/interval/BinomialConfidenceInterval.java b/src/main/java/org/apache/commons/math4/stat/interval/BinomialConfidenceInterval.java
index 532679a..8639929 100644
--- a/src/main/java/org/apache/commons/math4/stat/interval/BinomialConfidenceInterval.java
+++ b/src/main/java/org/apache/commons/math4/stat/interval/BinomialConfidenceInterval.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.interval;
+package org.apache.commons.math4.stat.interval;
 
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.exception.OutOfRangeException;
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
+import org.apache.commons.math4.exception.OutOfRangeException;
 
 /**
  * Interface to generate confidence intervals for a binomial proportion.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/interval/ClopperPearsonInterval.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/interval/ClopperPearsonInterval.java b/src/main/java/org/apache/commons/math4/stat/interval/ClopperPearsonInterval.java
index 34a0d57..ea713d8 100644
--- a/src/main/java/org/apache/commons/math4/stat/interval/ClopperPearsonInterval.java
+++ b/src/main/java/org/apache/commons/math4/stat/interval/ClopperPearsonInterval.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.interval;
+package org.apache.commons.math4.stat.interval;
 
-import org.apache.commons.math3.distribution.FDistribution;
+import org.apache.commons.math4.distribution.FDistribution;
 
 /**
  * Implements the Clopper-Pearson method for creating a binomial proportion confidence interval.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/interval/ConfidenceInterval.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/interval/ConfidenceInterval.java b/src/main/java/org/apache/commons/math4/stat/interval/ConfidenceInterval.java
index 0147c8c..4cadd1f 100644
--- a/src/main/java/org/apache/commons/math4/stat/interval/ConfidenceInterval.java
+++ b/src/main/java/org/apache/commons/math4/stat/interval/ConfidenceInterval.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.interval;
+package org.apache.commons.math4.stat.interval;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Represents an interval estimate of a population parameter.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/interval/IntervalUtils.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/interval/IntervalUtils.java b/src/main/java/org/apache/commons/math4/stat/interval/IntervalUtils.java
index 0613c99..86a7949 100644
--- a/src/main/java/org/apache/commons/math4/stat/interval/IntervalUtils.java
+++ b/src/main/java/org/apache/commons/math4/stat/interval/IntervalUtils.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.interval;
+package org.apache.commons.math4.stat.interval;
 
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.exception.OutOfRangeException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Factory methods to generate confidence intervals for a binomial proportion.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/interval/NormalApproximationInterval.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/interval/NormalApproximationInterval.java b/src/main/java/org/apache/commons/math4/stat/interval/NormalApproximationInterval.java
index 25a213a..a81e58d 100644
--- a/src/main/java/org/apache/commons/math4/stat/interval/NormalApproximationInterval.java
+++ b/src/main/java/org/apache/commons/math4/stat/interval/NormalApproximationInterval.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.interval;
+package org.apache.commons.math4.stat.interval;
 
-import org.apache.commons.math3.distribution.NormalDistribution;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.distribution.NormalDistribution;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Implements the normal approximation method for creating a binomial proportion confidence interval.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/interval/WilsonScoreInterval.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/interval/WilsonScoreInterval.java b/src/main/java/org/apache/commons/math4/stat/interval/WilsonScoreInterval.java
index 9932835..0c91f62 100644
--- a/src/main/java/org/apache/commons/math4/stat/interval/WilsonScoreInterval.java
+++ b/src/main/java/org/apache/commons/math4/stat/interval/WilsonScoreInterval.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.interval;
+package org.apache.commons.math4.stat.interval;
 
-import org.apache.commons.math3.distribution.NormalDistribution;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.distribution.NormalDistribution;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Implements the Wilson score method for creating a binomial proportion confidence interval.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/interval/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/interval/package-info.java b/src/main/java/org/apache/commons/math4/stat/interval/package-info.java
index 34f43d9..0e1fa28 100644
--- a/src/main/java/org/apache/commons/math4/stat/interval/package-info.java
+++ b/src/main/java/org/apache/commons/math4/stat/interval/package-info.java
@@ -19,4 +19,4 @@
  *      Classes providing binomial proportion confidence interval construction.
  *
  */
-package org.apache.commons.math3.stat.interval;
+package org.apache.commons.math4.stat.interval;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/package-info.java b/src/main/java/org/apache/commons/math4/stat/package-info.java
index 0df9424..4919e19 100644
--- a/src/main/java/org/apache/commons/math4/stat/package-info.java
+++ b/src/main/java/org/apache/commons/math4/stat/package-info.java
@@ -17,4 +17,4 @@
 /**
  * Data storage, manipulation and summary routines.
  */
-package org.apache.commons.math3.stat;
+package org.apache.commons.math4.stat;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/ranking/NaNStrategy.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/ranking/NaNStrategy.java b/src/main/java/org/apache/commons/math4/stat/ranking/NaNStrategy.java
index 1a916ef..7752103 100644
--- a/src/main/java/org/apache/commons/math4/stat/ranking/NaNStrategy.java
+++ b/src/main/java/org/apache/commons/math4/stat/ranking/NaNStrategy.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.ranking;
+package org.apache.commons.math4.stat.ranking;
 
 /**
  * Strategies for handling NaN values in rank transformations.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/ranking/NaturalRanking.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/ranking/NaturalRanking.java b/src/main/java/org/apache/commons/math4/stat/ranking/NaturalRanking.java
index feaa510..6e29cb6 100644
--- a/src/main/java/org/apache/commons/math4/stat/ranking/NaturalRanking.java
+++ b/src/main/java/org/apache/commons/math4/stat/ranking/NaturalRanking.java
@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.ranking;
+package org.apache.commons.math4.stat.ranking;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 
-import org.apache.commons.math3.exception.MathInternalError;
-import org.apache.commons.math3.exception.NotANumberException;
-import org.apache.commons.math3.random.RandomDataGenerator;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.MathInternalError;
+import org.apache.commons.math4.exception.NotANumberException;
+import org.apache.commons.math4.random.RandomDataGenerator;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.util.FastMath;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/ranking/RankingAlgorithm.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/ranking/RankingAlgorithm.java b/src/main/java/org/apache/commons/math4/stat/ranking/RankingAlgorithm.java
index 188bc99..69837f7 100644
--- a/src/main/java/org/apache/commons/math4/stat/ranking/RankingAlgorithm.java
+++ b/src/main/java/org/apache/commons/math4/stat/ranking/RankingAlgorithm.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.ranking;
+package org.apache.commons.math4.stat.ranking;
 
 /**
  * Interface representing a rank transformation.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/ranking/TiesStrategy.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/ranking/TiesStrategy.java b/src/main/java/org/apache/commons/math4/stat/ranking/TiesStrategy.java
index 08ab99a..2ae3352 100644
--- a/src/main/java/org/apache/commons/math4/stat/ranking/TiesStrategy.java
+++ b/src/main/java/org/apache/commons/math4/stat/ranking/TiesStrategy.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.ranking;
+package org.apache.commons.math4.stat.ranking;
 
 /**
  * Strategies for handling tied values in rank transformations.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/ranking/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/ranking/package-info.java b/src/main/java/org/apache/commons/math4/stat/ranking/package-info.java
index b86575b..e37d851 100644
--- a/src/main/java/org/apache/commons/math4/stat/ranking/package-info.java
+++ b/src/main/java/org/apache/commons/math4/stat/ranking/package-info.java
@@ -19,4 +19,4 @@
  *      Classes providing rank transformations.
  *
  */
-package org.apache.commons.math3.stat.ranking;
+package org.apache.commons.math4.stat.ranking;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/AbstractMultipleLinearRegression.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/AbstractMultipleLinearRegression.java b/src/main/java/org/apache/commons/math4/stat/regression/AbstractMultipleLinearRegression.java
index 9b7c40a..0b9751a 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/AbstractMultipleLinearRegression.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/AbstractMultipleLinearRegression.java
@@ -14,21 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.InsufficientDataException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NoDataException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.linear.NonSquareMatrixException;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.linear.RealVector;
-import org.apache.commons.math3.linear.ArrayRealVector;
-import org.apache.commons.math3.stat.descriptive.moment.Variance;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.InsufficientDataException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NoDataException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.linear.ArrayRealVector;
+import org.apache.commons.math4.linear.NonSquareMatrixException;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.linear.RealVector;
+import org.apache.commons.math4.stat.descriptive.moment.Variance;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Abstract base class for implementations of MultipleLinearRegression.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/GLSMultipleLinearRegression.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/GLSMultipleLinearRegression.java b/src/main/java/org/apache/commons/math4/stat/regression/GLSMultipleLinearRegression.java
index 1644e6d..f5981d4 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/GLSMultipleLinearRegression.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/GLSMultipleLinearRegression.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 
-import org.apache.commons.math3.linear.LUDecomposition;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.linear.RealVector;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.linear.LUDecomposition;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.linear.RealVector;
 
 /**
  * The GLS implementation of multiple linear regression.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/MillerUpdatingRegression.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/MillerUpdatingRegression.java b/src/main/java/org/apache/commons/math4/stat/regression/MillerUpdatingRegression.java
index 3fe3c03..c7a1003 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/MillerUpdatingRegression.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/MillerUpdatingRegression.java
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 
 import java.util.Arrays;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.Precision;
-import org.apache.commons.math3.util.MathArrays;
+
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathArrays;
+import org.apache.commons.math4.util.Precision;
 
 /**
  * This class is a concrete implementation of the {@link UpdatingMultipleLinearRegression} interface.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/ModelSpecificationException.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/ModelSpecificationException.java b/src/main/java/org/apache/commons/math4/stat/regression/ModelSpecificationException.java
index f3804db..248234d 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/ModelSpecificationException.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/ModelSpecificationException.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.Localizable;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.Localizable;
 
 /**
  * Exception thrown when a regression model is not correctly specified.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/MultipleLinearRegression.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/MultipleLinearRegression.java b/src/main/java/org/apache/commons/math4/stat/regression/MultipleLinearRegression.java
index 866214f..7a0c09e 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/MultipleLinearRegression.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/MultipleLinearRegression.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 
 /**
  * The multiple linear regression can be represented in matrix-notation.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/OLSMultipleLinearRegression.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/RegressionResults.java b/src/main/java/org/apache/commons/math4/stat/regression/RegressionResults.java
index 70faeac..bc8f3c1 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/RegressionResults.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/RegressionResults.java
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 
 import java.io.Serializable;
 import java.util.Arrays;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.MathArrays;
-import org.apache.commons.math3.exception.OutOfRangeException;
+
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathArrays;
 
 /**
  * Results of a Multiple Linear Regression model fit.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/SimpleRegression.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/SimpleRegression.java b/src/main/java/org/apache/commons/math4/stat/regression/SimpleRegression.java
index 02bf8f4..38f2e63 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/SimpleRegression.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/SimpleRegression.java
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 import java.io.Serializable;
 
-import org.apache.commons.math3.distribution.TDistribution;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NoDataException;
-import org.apache.commons.math3.exception.OutOfRangeException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.Precision;
+import org.apache.commons.math4.distribution.TDistribution;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NoDataException;
+import org.apache.commons.math4.exception.OutOfRangeException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.Precision;
 
 /**
  * Estimates an ordinary least squares regression model
@@ -716,7 +716,7 @@ public class SimpleRegression implements Serializable, UpdatingMultipleLinearReg
      * <code>Double.NaN</code>.</p>
      *
      * @return significance level for slope/correlation
-     * @throws org.apache.commons.math3.exception.MaxCountExceededException
+     * @throws org.apache.commons.math4.exception.MaxCountExceededException
      * if the significance level can not be computed.
      */
     public double getSignificance() {

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/UpdatingMultipleLinearRegression.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/UpdatingMultipleLinearRegression.java b/src/main/java/org/apache/commons/math4/stat/regression/UpdatingMultipleLinearRegression.java
index ebefc31..60a0534 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/UpdatingMultipleLinearRegression.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/UpdatingMultipleLinearRegression.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NoDataException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NoDataException;
 
 /**
  * An interface for regression models allowing for dynamic updating of the data.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/package-info.java b/src/main/java/org/apache/commons/math4/stat/regression/package-info.java
index fbc0e12..ad05581 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/package-info.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/package-info.java
@@ -19,4 +19,4 @@
  *      Statistical routines involving multivariate data.
  *
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/DctNormalization.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/DctNormalization.java b/src/main/java/org/apache/commons/math4/transform/DctNormalization.java
index b355013..b1221af 100644
--- a/src/main/java/org/apache/commons/math4/transform/DctNormalization.java
+++ b/src/main/java/org/apache/commons/math4/transform/DctNormalization.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 /**
  * This enumeration defines the various types of normalizations that can be

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/DftNormalization.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/DftNormalization.java b/src/main/java/org/apache/commons/math4/transform/DftNormalization.java
index 8bc1888..928d1b2 100644
--- a/src/main/java/org/apache/commons/math4/transform/DftNormalization.java
+++ b/src/main/java/org/apache/commons/math4/transform/DftNormalization.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 /**
  * This enumeration defines the various types of normalizations that can be

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/DstNormalization.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/DstNormalization.java b/src/main/java/org/apache/commons/math4/transform/DstNormalization.java
index a65eca3..3957bb7 100644
--- a/src/main/java/org/apache/commons/math4/transform/DstNormalization.java
+++ b/src/main/java/org/apache/commons/math4/transform/DstNormalization.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 /**
  * This enumeration defines the various types of normalizations that can be

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/FastCosineTransformer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/FastCosineTransformer.java b/src/main/java/org/apache/commons/math4/transform/FastCosineTransformer.java
index c83a215..0884701 100644
--- a/src/main/java/org/apache/commons/math4/transform/FastCosineTransformer.java
+++ b/src/main/java/org/apache/commons/math4/transform/FastCosineTransformer.java
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.analysis.FunctionUtils;
-import org.apache.commons.math3.analysis.UnivariateFunction;
-import org.apache.commons.math3.complex.Complex;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.ArithmeticUtils;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.analysis.FunctionUtils;
+import org.apache.commons.math4.analysis.UnivariateFunction;
+import org.apache.commons.math4.complex.Complex;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.ArithmeticUtils;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Implements the Fast Cosine Transform for transformation of one-dimensional
@@ -109,9 +109,9 @@ public class FastCosineTransformer implements RealTransformer, Serializable {
     /**
      * {@inheritDoc}
      *
-     * @throws org.apache.commons.math3.exception.NonMonotonicSequenceException
+     * @throws org.apache.commons.math4.exception.NonMonotonicSequenceException
      * if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      * if the number of sample points is negative
      * @throws MathIllegalArgumentException if the number of sample points is
      * not a power of two plus one

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/FastFourierTransformer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/FastFourierTransformer.java b/src/main/java/org/apache/commons/math4/transform/FastFourierTransformer.java
index ca62c19..b829367 100644
--- a/src/main/java/org/apache/commons/math4/transform/FastFourierTransformer.java
+++ b/src/main/java/org/apache/commons/math4/transform/FastFourierTransformer.java
@@ -14,21 +14,21 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 import java.io.Serializable;
 import java.lang.reflect.Array;
 
-import org.apache.commons.math3.analysis.FunctionUtils;
-import org.apache.commons.math3.analysis.UnivariateFunction;
-import org.apache.commons.math3.complex.Complex;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.MathIllegalStateException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.ArithmeticUtils;
-import org.apache.commons.math3.util.FastMath;
-import org.apache.commons.math3.util.MathArrays;
+import org.apache.commons.math4.analysis.FunctionUtils;
+import org.apache.commons.math4.analysis.UnivariateFunction;
+import org.apache.commons.math4.complex.Complex;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalStateException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.ArithmeticUtils;
+import org.apache.commons.math4.util.FastMath;
+import org.apache.commons.math4.util.MathArrays;
 
 /**
  * Implements the Fast Fourier Transform for transformation of one-dimensional
@@ -386,9 +386,9 @@ public class FastFourierTransformer implements Serializable {
      * @param n the number of sample points
      * @param type the type of transform (forward, inverse) to be performed
      * @return the complex transformed array
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException
      *   if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      *   if the number of sample points {@code n} is negative
      * @throws MathIllegalArgumentException if the number of sample points
      *   {@code n} is not a power of two

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/FastHadamardTransformer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/FastHadamardTransformer.java b/src/main/java/org/apache/commons/math4/transform/FastHadamardTransformer.java
index f0777c7..d6b3ad9 100644
--- a/src/main/java/org/apache/commons/math4/transform/FastHadamardTransformer.java
+++ b/src/main/java/org/apache/commons/math4/transform/FastHadamardTransformer.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.analysis.FunctionUtils;
-import org.apache.commons.math3.analysis.UnivariateFunction;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.ArithmeticUtils;
+import org.apache.commons.math4.analysis.FunctionUtils;
+import org.apache.commons.math4.analysis.UnivariateFunction;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.ArithmeticUtils;
 
 /**
  * Implements the <a href="http://www.archive.chipcenter.com/dsp/DSP000517F1.html">Fast Hadamard Transform</a> (FHT).
@@ -57,9 +57,9 @@ public class FastHadamardTransformer implements RealTransformer, Serializable {
     /**
      * {@inheritDoc}
      *
-     * @throws org.apache.commons.math3.exception.NonMonotonicSequenceException
+     * @throws org.apache.commons.math4.exception.NonMonotonicSequenceException
      *   if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      *   if the number of sample points is negative
      * @throws MathIllegalArgumentException if the number of sample points is not a power of two
      */

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/FastSineTransformer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/FastSineTransformer.java b/src/main/java/org/apache/commons/math4/transform/FastSineTransformer.java
index 28e8b47..34a94ef 100644
--- a/src/main/java/org/apache/commons/math4/transform/FastSineTransformer.java
+++ b/src/main/java/org/apache/commons/math4/transform/FastSineTransformer.java
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.analysis.FunctionUtils;
-import org.apache.commons.math3.analysis.UnivariateFunction;
-import org.apache.commons.math3.complex.Complex;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.util.ArithmeticUtils;
-import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math4.analysis.FunctionUtils;
+import org.apache.commons.math4.analysis.UnivariateFunction;
+import org.apache.commons.math4.complex.Complex;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.util.ArithmeticUtils;
+import org.apache.commons.math4.util.FastMath;
 
 /**
  * Implements the Fast Sine Transform for transformation of one-dimensional real
@@ -109,9 +109,9 @@ public class FastSineTransformer implements RealTransformer, Serializable {
      *
      * This implementation enforces {@code f(x) = 0.0} at {@code x = 0.0}.
      *
-     * @throws org.apache.commons.math3.exception.NonMonotonicSequenceException
+     * @throws org.apache.commons.math4.exception.NonMonotonicSequenceException
      *   if the lower bound is greater than, or equal to the upper bound
-     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math4.exception.NotStrictlyPositiveException
      *   if the number of sample points is negative
      * @throws MathIllegalArgumentException if the number of sample points is not a power of two
      */

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/RealTransformer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/RealTransformer.java b/src/main/java/org/apache/commons/math4/transform/RealTransformer.java
index 672a1cb..a53dfad 100644
--- a/src/main/java/org/apache/commons/math4/transform/RealTransformer.java
+++ b/src/main/java/org/apache/commons/math4/transform/RealTransformer.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
-import org.apache.commons.math3.analysis.UnivariateFunction;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NonMonotonicSequenceException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.analysis.UnivariateFunction;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NonMonotonicSequenceException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
 
 /**
  * Interface for one-dimensional data sets transformations producing real results.
@@ -28,7 +28,7 @@ import org.apache.commons.math3.exception.NotStrictlyPositiveException;
  * {@link FastCosineTransformer cosine transform} or {@link
  * FastHadamardTransformer Hadamard transform}. {@link FastFourierTransformer
  * Fourier transform} is of a different kind and does not implement this
- * interface since it produces {@link org.apache.commons.math3.complex.Complex}
+ * interface since it produces {@link org.apache.commons.math4.complex.Complex}
  * results instead of real ones.
  *
  * @since 2.0

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/TransformType.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/TransformType.java b/src/main/java/org/apache/commons/math4/transform/TransformType.java
index ae1a6c5..b4d84cf 100644
--- a/src/main/java/org/apache/commons/math4/transform/TransformType.java
+++ b/src/main/java/org/apache/commons/math4/transform/TransformType.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 /**
  * This enumeration defines the type of transform which is to be computed.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/TransformUtils.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/TransformUtils.java b/src/main/java/org/apache/commons/math4/transform/TransformUtils.java
index 17cbb00..27915b2 100644
--- a/src/main/java/org/apache/commons/math4/transform/TransformUtils.java
+++ b/src/main/java/org/apache/commons/math4/transform/TransformUtils.java
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;
 
 import java.util.Arrays;
 
-import org.apache.commons.math3.complex.Complex;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.complex.Complex;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Useful functions for the implementation of various transforms.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/transform/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/transform/package-info.java b/src/main/java/org/apache/commons/math4/transform/package-info.java
index 6d6cfc6..bc64c9c 100644
--- a/src/main/java/org/apache/commons/math4/transform/package-info.java
+++ b/src/main/java/org/apache/commons/math4/transform/package-info.java
@@ -19,4 +19,4 @@
  *     Implementations of transform methods, including Fast Fourier transforms.
  *
  */
-package org.apache.commons.math3.transform;
+package org.apache.commons.math4.transform;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/ArithmeticUtils.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/ArithmeticUtils.java b/src/main/java/org/apache/commons/math4/util/ArithmeticUtils.java
index ed51142..027fa29 100644
--- a/src/main/java/org/apache/commons/math4/util/ArithmeticUtils.java
+++ b/src/main/java/org/apache/commons/math4/util/ArithmeticUtils.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.math.BigInteger;
 
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.exception.util.Localizable;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
+import org.apache.commons.math4.exception.util.Localizable;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Some useful, arithmetics related, additions to the built-in functions in

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/BigReal.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/BigReal.java b/src/main/java/org/apache/commons/math4/util/BigReal.java
index 678eabd..cd3a7d4 100644
--- a/src/main/java/org/apache/commons/math4/util/BigReal.java
+++ b/src/main/java/org/apache/commons/math4/util/BigReal.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 
 import java.io.Serializable;
@@ -23,10 +23,10 @@ import java.math.BigInteger;
 import java.math.MathContext;
 import java.math.RoundingMode;
 
-import org.apache.commons.math3.Field;
-import org.apache.commons.math3.FieldElement;
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.Field;
+import org.apache.commons.math4.FieldElement;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Arbitrary precision decimal number.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/BigRealField.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/BigRealField.java b/src/main/java/org/apache/commons/math4/util/BigRealField.java
index c748087..ce8ff5b 100644
--- a/src/main/java/org/apache/commons/math4/util/BigRealField.java
+++ b/src/main/java/org/apache/commons/math4/util/BigRealField.java
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.Field;
-import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math4.Field;
+import org.apache.commons.math4.FieldElement;
 
 /**
  * Representation of real numbers with arbitrary precision field.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/CentralPivotingStrategy.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/CentralPivotingStrategy.java b/src/main/java/org/apache/commons/math4/util/CentralPivotingStrategy.java
index eacbf21..8d19b6d 100644
--- a/src/main/java/org/apache/commons/math4/util/CentralPivotingStrategy.java
+++ b/src/main/java/org/apache/commons/math4/util/CentralPivotingStrategy.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/Combinations.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/CombinatoricsUtils.java b/src/main/java/org/apache/commons/math4/util/CombinatoricsUtils.java
index e43d549..0ca2e75 100644
--- a/src/main/java/org/apache/commons/math4/util/CombinatoricsUtils.java
+++ b/src/main/java/org/apache/commons/math4/util/CombinatoricsUtils.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.Iterator;
 import java.util.concurrent.atomic.AtomicReference;
 
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Combinatorial utilities.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/CompositeFormat.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/CompositeFormat.java b/src/main/java/org/apache/commons/math4/util/CompositeFormat.java
index 043b66e..40809ba 100644
--- a/src/main/java/org/apache/commons/math4/util/CompositeFormat.java
+++ b/src/main/java/org/apache/commons/math4/util/CompositeFormat.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.text.FieldPosition;
 import java.text.NumberFormat;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/ContinuedFraction.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/ContinuedFraction.java b/src/main/java/org/apache/commons/math4/util/ContinuedFraction.java
index e4bac0b..56b7267 100644
--- a/src/main/java/org/apache/commons/math4/util/ContinuedFraction.java
+++ b/src/main/java/org/apache/commons/math4/util/ContinuedFraction.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
-import org.apache.commons.math3.exception.ConvergenceException;
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.ConvergenceException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Provides a generic means to evaluate continued fractions.  Subclasses simply

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/Decimal64.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/Decimal64.java b/src/main/java/org/apache/commons/math4/util/Decimal64.java
index e5c9607..15c174d 100644
--- a/src/main/java/org/apache/commons/math4/util/Decimal64.java
+++ b/src/main/java/org/apache/commons/math4/util/Decimal64.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
-import org.apache.commons.math3.RealFieldElement;
-import org.apache.commons.math3.Field;
-import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math4.Field;
+import org.apache.commons.math4.RealFieldElement;
+import org.apache.commons.math4.exception.DimensionMismatchException;
 
 /**
  * This class wraps a {@code double} value in an object. It is similar to the

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/Decimal64Field.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/Decimal64Field.java b/src/main/java/org/apache/commons/math4/util/Decimal64Field.java
index 2b07826..67117f2 100644
--- a/src/main/java/org/apache/commons/math4/util/Decimal64Field.java
+++ b/src/main/java/org/apache/commons/math4/util/Decimal64Field.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
-import org.apache.commons.math3.Field;
-import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math4.Field;
+import org.apache.commons.math4.FieldElement;
 
 /**
  * The field of double precision floating-point numbers.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/DefaultTransformer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/DefaultTransformer.java b/src/main/java/org/apache/commons/math4/util/DefaultTransformer.java
index 6128a88..b0d2078 100644
--- a/src/main/java/org/apache/commons/math4/util/DefaultTransformer.java
+++ b/src/main/java/org/apache/commons/math4/util/DefaultTransformer.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.exception.util.LocalizedFormats;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * A Default NumberTransformer for java.lang.Numbers and Numeric Strings. This

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/DoubleArray.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/DoubleArray.java b/src/main/java/org/apache/commons/math4/util/DoubleArray.java
index f7d9d25..371bd84 100644
--- a/src/main/java/org/apache/commons/math4/util/DoubleArray.java
+++ b/src/main/java/org/apache/commons/math4/util/DoubleArray.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/FastMath.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/FastMath.java b/src/main/java/org/apache/commons/math4/util/FastMath.java
index b1e3c0a..b88183c 100644
--- a/src/main/java/org/apache/commons/math4/util/FastMath.java
+++ b/src/main/java/org/apache/commons/math4/util/FastMath.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.PrintStream;
 
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Faster, more accurate, portable alternative to {@link Math} and

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/FastMathCalc.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/FastMathCalc.java b/src/main/java/org/apache/commons/math4/util/FastMathCalc.java
index be2a2fb..7beba2a 100644
--- a/src/main/java/org/apache/commons/math4/util/FastMathCalc.java
+++ b/src/main/java/org/apache/commons/math4/util/FastMathCalc.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.PrintStream;
 
-import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.DimensionMismatchException;
 
 /** Class used to compute the classical functions tables.
  * @since 3.0

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/FastMathLiteralArrays.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/FastMathLiteralArrays.java b/src/main/java/org/apache/commons/math4/util/FastMathLiteralArrays.java
index d7b00e3..90bbf67 100644
--- a/src/main/java/org/apache/commons/math4/util/FastMathLiteralArrays.java
+++ b/src/main/java/org/apache/commons/math4/util/FastMathLiteralArrays.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 /**
  * Utility class for loading tabulated data used by {@link FastMath}.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/Incrementor.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/Incrementor.java b/src/main/java/org/apache/commons/math4/util/Incrementor.java
index a351dc8..c63081d 100644
--- a/src/main/java/org/apache/commons/math4/util/Incrementor.java
+++ b/src/main/java/org/apache/commons/math4/util/Incrementor.java
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
-import org.apache.commons.math3.exception.MaxCountExceededException;
-import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.NullArgumentException;
 
 /**
  * Utility that increments a counter until a maximum is reached, at

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/IterationEvent.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/IterationEvent.java b/src/main/java/org/apache/commons/math4/util/IterationEvent.java
index 29194ca..5e58b17 100644
--- a/src/main/java/org/apache/commons/math4/util/IterationEvent.java
+++ b/src/main/java/org/apache/commons/math4/util/IterationEvent.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.EventObject;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/IterationListener.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/IterationListener.java b/src/main/java/org/apache/commons/math4/util/IterationListener.java
index f9d7cd8..b6c1157 100644
--- a/src/main/java/org/apache/commons/math4/util/IterationListener.java
+++ b/src/main/java/org/apache/commons/math4/util/IterationListener.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.EventListener;
 

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/IterationManager.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/IterationManager.java b/src/main/java/org/apache/commons/math4/util/IterationManager.java
index 1a80d3a..4437a8f 100644
--- a/src/main/java/org/apache/commons/math4/util/IterationManager.java
+++ b/src/main/java/org/apache/commons/math4/util/IterationManager.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.Collection;
 import java.util.concurrent.CopyOnWriteArrayList;
 
-import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math4.exception.MaxCountExceededException;
 
 /**
  * This abstract class provides a general framework for managing iterative
@@ -52,7 +52,7 @@ public class IterationManager {
      * @param maxIterations the maximum number of iterations
      * @param callBack the function to be called when the maximum number of
      * iterations has been reached
-     * @throws org.apache.commons.math3.exception.NullArgumentException if {@code callBack} is {@code null}
+     * @throws org.apache.commons.math4.exception.NullArgumentException if {@code callBack} is {@code null}
      * @since 3.1
      */
     public IterationManager(final int maxIterations,

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/KthSelector.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/KthSelector.java b/src/main/java/org/apache/commons/math4/util/KthSelector.java
index 391c548..9a71a2f 100644
--- a/src/main/java/org/apache/commons/math4/util/KthSelector.java
+++ b/src/main/java/org/apache/commons/math4/util/KthSelector.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math4.exception.NullArgumentException;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/MathArrays.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/MathArrays.java b/src/main/java/org/apache/commons/math4/util/MathArrays.java
index a9e11b9..d7f7928 100644
--- a/src/main/java/org/apache/commons/math4/util/MathArrays.java
+++ b/src/main/java/org/apache/commons/math4/util/MathArrays.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.lang.reflect.Array;
 import java.util.ArrayList;
@@ -24,22 +24,22 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.List;
 
-import org.apache.commons.math3.Field;
-import org.apache.commons.math3.random.RandomGenerator;
-import org.apache.commons.math3.random.Well19937c;
-import org.apache.commons.math3.distribution.UniformIntegerDistribution;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.MathInternalError;
-import org.apache.commons.math3.exception.NoDataException;
-import org.apache.commons.math3.exception.NonMonotonicSequenceException;
-import org.apache.commons.math3.exception.NotPositiveException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.NumberIsTooLargeException;
-import org.apache.commons.math3.exception.NotANumberException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.Field;
+import org.apache.commons.math4.distribution.UniformIntegerDistribution;
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathInternalError;
+import org.apache.commons.math4.exception.NoDataException;
+import org.apache.commons.math4.exception.NonMonotonicSequenceException;
+import org.apache.commons.math4.exception.NotANumberException;
+import org.apache.commons.math4.exception.NotPositiveException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.NumberIsTooLargeException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
+import org.apache.commons.math4.random.RandomGenerator;
+import org.apache.commons.math4.random.Well19937c;
 
 /**
  * Arrays utilities.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/MathUtils.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/MathUtils.java b/src/main/java/org/apache/commons/math4/util/MathUtils.java
index 0b5fc56..8e11026 100644
--- a/src/main/java/org/apache/commons/math4/util/MathUtils.java
+++ b/src/main/java/org/apache/commons/math4/util/MathUtils.java
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.Arrays;
 
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.NotFiniteNumberException;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.util.Localizable;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.NotFiniteNumberException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.util.Localizable;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Miscellaneous utility functions.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/MedianOf3PivotingStrategy.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/MedianOf3PivotingStrategy.java b/src/main/java/org/apache/commons/math4/util/MedianOf3PivotingStrategy.java
index b167d9e..0eaa6a2 100644
--- a/src/main/java/org/apache/commons/math4/util/MedianOf3PivotingStrategy.java
+++ b/src/main/java/org/apache/commons/math4/util/MedianOf3PivotingStrategy.java
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/MultidimensionalCounter.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/MultidimensionalCounter.java b/src/main/java/org/apache/commons/math4/util/MultidimensionalCounter.java
index 57573d8..58b8445 100644
--- a/src/main/java/org/apache/commons/math4/util/MultidimensionalCounter.java
+++ b/src/main/java/org/apache/commons/math4/util/MultidimensionalCounter.java
@@ -15,12 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.NoSuchElementException;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.OutOfRangeException;
+
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.OutOfRangeException;
 
 /**
  * Converter between unidimensional storage structure and multidimensional

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/NumberTransformer.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/NumberTransformer.java b/src/main/java/org/apache/commons/math4/util/NumberTransformer.java
index 79a6414..8c411ab 100644
--- a/src/main/java/org/apache/commons/math4/util/NumberTransformer.java
+++ b/src/main/java/org/apache/commons/math4/util/NumberTransformer.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
 
 /**
  * Subclasses implementing this interface can transform Objects to doubles.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/OpenIntToDoubleHashMap.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/OpenIntToDoubleHashMap.java b/src/main/java/org/apache/commons/math4/util/OpenIntToDoubleHashMap.java
index 9fb3e0a..b03ca95 100644
--- a/src/main/java/org/apache/commons/math4/util/OpenIntToDoubleHashMap.java
+++ b/src/main/java/org/apache/commons/math4/util/OpenIntToDoubleHashMap.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/OpenIntToFieldHashMap.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/OpenIntToFieldHashMap.java b/src/main/java/org/apache/commons/math4/util/OpenIntToFieldHashMap.java
index df628a5..1fb034a 100644
--- a/src/main/java/org/apache/commons/math4/util/OpenIntToFieldHashMap.java
+++ b/src/main/java/org/apache/commons/math4/util/OpenIntToFieldHashMap.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;
@@ -23,8 +23,8 @@ import java.lang.reflect.Array;
 import java.util.ConcurrentModificationException;
 import java.util.NoSuchElementException;
 
-import org.apache.commons.math3.Field;
-import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math4.Field;
+import org.apache.commons.math4.FieldElement;
 
 /**
  * Open addressed map from int to FieldElement.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/Pair.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/Pair.java b/src/main/java/org/apache/commons/math4/util/Pair.java
index ecdca37..6bdecdf 100644
--- a/src/main/java/org/apache/commons/math4/util/Pair.java
+++ b/src/main/java/org/apache/commons/math4/util/Pair.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 /**
  * Generic pair.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/PivotingStrategyInterface.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/PivotingStrategyInterface.java b/src/main/java/org/apache/commons/math4/util/PivotingStrategyInterface.java
index 1914d31..36a3bcb 100644
--- a/src/main/java/org/apache/commons/math4/util/PivotingStrategyInterface.java
+++ b/src/main/java/org/apache/commons/math4/util/PivotingStrategyInterface.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/Precision.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/Precision.java b/src/main/java/org/apache/commons/math4/util/Precision.java
index 49fd15c..e2d0cc9 100644
--- a/src/main/java/org/apache/commons/math4/util/Precision.java
+++ b/src/main/java/org/apache/commons/math4/util/Precision.java
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.math.BigDecimal;
 
-import org.apache.commons.math3.exception.MathArithmeticException;
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathArithmeticException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * Utilities for comparing numbers.

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/RandomPivotingStrategy.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/RandomPivotingStrategy.java b/src/main/java/org/apache/commons/math4/util/RandomPivotingStrategy.java
index b9819bf..fa0374f 100644
--- a/src/main/java/org/apache/commons/math4/util/RandomPivotingStrategy.java
+++ b/src/main/java/org/apache/commons/math4/util/RandomPivotingStrategy.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.Serializable;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.random.RandomGenerator;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.random.RandomGenerator;
 
 
 /**

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/ResizableDoubleArray.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/ResizableDoubleArray.java b/src/main/java/org/apache/commons/math4/util/ResizableDoubleArray.java
index 468ed74..3fd29f3 100644
--- a/src/main/java/org/apache/commons/math4/util/ResizableDoubleArray.java
+++ b/src/main/java/org/apache/commons/math4/util/ResizableDoubleArray.java
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.Serializable;
 import java.util.Arrays;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.exception.MathIllegalStateException;
-import org.apache.commons.math3.exception.MathInternalError;
-import org.apache.commons.math3.exception.NullArgumentException;
-import org.apache.commons.math3.exception.NotStrictlyPositiveException;
-import org.apache.commons.math3.exception.NumberIsTooSmallException;
-import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalStateException;
+import org.apache.commons.math4.exception.MathInternalError;
+import org.apache.commons.math4.exception.NotStrictlyPositiveException;
+import org.apache.commons.math4.exception.NullArgumentException;
+import org.apache.commons.math4.exception.NumberIsTooSmallException;
+import org.apache.commons.math4.exception.util.LocalizedFormats;
 
 /**
  * <p>

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/TransformerMap.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/TransformerMap.java b/src/main/java/org/apache/commons/math4/util/TransformerMap.java
index de09669..c5b9ce0 100644
--- a/src/main/java/org/apache/commons/math4/util/TransformerMap.java
+++ b/src/main/java/org/apache/commons/math4/util/TransformerMap.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.io.Serializable;
 import java.util.Collection;
@@ -22,7 +22,7 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
 
 /**
  * This TansformerMap automates the transformation of mixed object types.
@@ -135,7 +135,7 @@ public class TransformerMap implements NumberTransformer, Serializable {
      * @return the double value of the Object.
      * @throws MathIllegalArgumentException if the Object can not be
      * transformed into a Double.
-     * @see org.apache.commons.math3.util.NumberTransformer#transform(java.lang.Object)
+     * @see org.apache.commons.math4.util.NumberTransformer#transform(java.lang.Object)
      */
     public double transform(Object o) throws MathIllegalArgumentException {
         double value = Double.NaN;

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/package-info.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/commons/math4/util/package-info.java b/src/main/java/org/apache/commons/math4/util/package-info.java
index 5d75341..80f385b 100644
--- a/src/main/java/org/apache/commons/math4/util/package-info.java
+++ b/src/main/java/org/apache/commons/math4/util/package-info.java
@@ -17,4 +17,4 @@
 /**
  * Convenience routines and common data structures used throughout the commons-math library.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
diff --git a/src/main/java/org/apache/commons/math4/stat/regression/OLSMultipleLinearRegression.java b/src/main/java/org/apache/commons/math4/stat/regression/OLSMultipleLinearRegression.java
index 7fff940..38b38c1 100644
--- a/src/main/java/org/apache/commons/math4/stat/regression/OLSMultipleLinearRegression.java
+++ b/src/main/java/org/apache/commons/math4/stat/regression/OLSMultipleLinearRegression.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.stat.regression;
+package org.apache.commons.math4.stat.regression;
 
-import org.apache.commons.math3.exception.MathIllegalArgumentException;
-import org.apache.commons.math3.linear.Array2DRowRealMatrix;
-import org.apache.commons.math3.linear.LUDecomposition;
-import org.apache.commons.math3.linear.QRDecomposition;
-import org.apache.commons.math3.linear.RealMatrix;
-import org.apache.commons.math3.linear.RealVector;
-import org.apache.commons.math3.stat.StatUtils;
-import org.apache.commons.math3.stat.descriptive.moment.SecondMoment;
+import org.apache.commons.math4.exception.MathIllegalArgumentException;
+import org.apache.commons.math4.linear.Array2DRowRealMatrix;
+import org.apache.commons.math4.linear.LUDecomposition;
+import org.apache.commons.math4.linear.QRDecomposition;
+import org.apache.commons.math4.linear.RealMatrix;
+import org.apache.commons.math4.linear.RealVector;
+import org.apache.commons.math4.stat.StatUtils;
+import org.apache.commons.math4.stat.descriptive.moment.SecondMoment;
 
 /**
  * <p>Implements ordinary least squares (OLS) to estimate the parameters of a
@@ -173,7 +173,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      *
      * @return residual sum of squares
      * @since 2.2
      * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
      * @throws NullPointerException if the data for the model have not been loaded
      */
     public double calculateResidualSumOfSquares() {
@@ -193,7 +193,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      *
      * @return R-square statistic
      * @throws NullPointerException if the sample has not been set
      * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
      * @since 2.2
      */
     public double calculateRSquared() {
@@ -216,7 +216,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      *
      * @return adjusted R-Squared statistic
      * @throws NullPointerException if the sample has not been set
      * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
      * @see #isNoIntercept()
      * @since 2.2
      */
@@ -249,7 +249,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      * a {@code NullPointerException} will be thrown.</p>
      *
      * @return beta
      * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
      * @throws NullPointerException if the data for the model have not been loaded
      */
     @Override
@@ -271,7 +271,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      * a {@code NullPointerException} will be thrown.</p>
      *
      * @return The beta variance-covariance matrix
      * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
      * @throws NullPointerException if the data for the model have not been loaded
      */
     @Override

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/stat/regression/RegressionResults.java
----------------------------------------------------------------------
@@ -173,7 +173,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      * @return residual sum of squares
      * @since 2.2
-     * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
+     * @throws org.apache.commons.math4.linear.SingularMatrixException if the design matrix is singular
      * @throws NullPointerException if the data for the model have not been loaded
      */
@@ -193,7 +193,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      * @return R-square statistic
      * @throws NullPointerException if the sample has not been set
-     * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
+     * @throws org.apache.commons.math4.linear.SingularMatrixException if the design matrix is singular
      * @since 2.2
      */
@@ -216,7 +216,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      * @return adjusted R-Squared statistic
      * @throws NullPointerException if the sample has not been set
-     * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
+     * @throws org.apache.commons.math4.linear.SingularMatrixException if the design matrix is singular
      * @see #isNoIntercept()
      * @since 2.2
@@ -249,7 +249,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      *
      * @return beta
-     * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
+     * @throws org.apache.commons.math4.linear.SingularMatrixException if the design matrix is singular
      * @throws NullPointerException if the data for the model have not been loaded
      */
@@ -271,7 +271,7 @@ public class OLSMultipleLinearRegression extends AbstractMultipleLinearRegressio
      *
      * @return The beta variance-covariance matrix
-     * @throws org.apache.commons.math3.linear.SingularMatrixException if the design matrix is singular
+     * @throws org.apache.commons.math4.linear.SingularMatrixException if the design matrix is singular
      * @throws NullPointerException if the data for the model have not been loaded
      */
diff --git a/src/main/java/org/apache/commons/math4/util/Combinations.java b/src/main/java/org/apache/commons/math4/util/Combinations.java
index f0a0fc3..8079ba5 100644
--- a/src/main/java/org/apache/commons/math4/util/Combinations.java
+++ b/src/main/java/org/apache/commons/math4/util/Combinations.java
@@ -14,16 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math3.util;
+package org.apache.commons.math4.util;
 
 import java.util.Iterator;
 import java.util.Comparator;
 import java.util.Arrays;
 import java.util.NoSuchElementException;
 import java.io.Serializable;
-import org.apache.commons.math3.exception.MathInternalError;
-import org.apache.commons.math3.exception.DimensionMismatchException;
-import org.apache.commons.math3.exception.OutOfRangeException;
+
+import org.apache.commons.math4.exception.DimensionMismatchException;
+import org.apache.commons.math4.exception.MathInternalError;
+import org.apache.commons.math4.exception.OutOfRangeException;
 
 /**
  * Utility to create <a href="http://en.wikipedia.org/wiki/Combination">
@@ -68,8 +69,8 @@ public class Combinations implements Iterable<int[]> {
      *
      * @param n Size of the set from which subsets are selected.
      * @param k Size of the subsets to be enumerated.
      * @throws org.apache.commons.math3.exception.NotPositiveException if {@code n < 0}.
      * @throws org.apache.commons.math3.exception.NumberIsTooLargeException if {@code k > n}.
      */
     public Combinations(int n,
                         int k) {
@@ -97,8 +98,8 @@ public class Combinations implements Iterable<int[]> {
      * @param n Size of the set from which subsets are selected.
      * @param k Size of the subsets to be enumerated.
      * @param iterationOrder Specifies the {@link #iterator() iteration order}.
      * @throws org.apache.commons.math3.exception.NotPositiveException if {@code n < 0}.
      * @throws org.apache.commons.math3.exception.NumberIsTooLargeException if {@code k > n}.
      */
     private Combinations(int n,
                          int k,

http://git-wip-us.apache.org/repos/asf/commons-math/blob/e4e1ac23/src/main/java/org/apache/commons/math4/util/CombinatoricsUtils.java
----------------------------------------------------------------------
@@ -68,8 +69,8 @@ public class Combinations implements Iterable<int[]> {
      * @param n Size of the set from which subsets are selected.
      * @param k Size of the subsets to be enumerated.
-     * @throws org.apache.commons.math3.exception.NotPositiveException if {@code n < 0}.
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException if {@code k > n}.
+     * @throws org.apache.commons.math4.exception.NotPositiveException if {@code n < 0}.
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException if {@code k > n}.
      */
     public Combinations(int n,
@@ -97,8 +98,8 @@ public class Combinations implements Iterable<int[]> {
      * @param k Size of the subsets to be enumerated.
      * @param iterationOrder Specifies the {@link #iterator() iteration order}.
-     * @throws org.apache.commons.math3.exception.NotPositiveException if {@code n < 0}.
-     * @throws org.apache.commons.math3.exception.NumberIsTooLargeException if {@code k > n}.
+     * @throws org.apache.commons.math4.exception.NotPositiveException if {@code n < 0}.
+     * @throws org.apache.commons.math4.exception.NumberIsTooLargeException if {@code k > n}.
      */
     private Combinations(int n,